/*
 *  Copyright (c) xlightweb.org, 2008 - 2009. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xlightweb.org/
 */
package org.xlightweb;

import java.io.IOException;
import java.nio.ByteBuffer;

import org.xlightweb.AbstractHttpConnection.IMultimodeExecutor;




/**
 * in-memory body data source
 * 
 * @author grro@xlightweb.org
 *
 */
final class InMemoryBodyDataSource extends NonBlockingBodyDataSource {
    
   
    InMemoryBodyDataSource(String characterEncoding, IMultimodeExecutor executor) throws IOException {
        super(characterEncoding, executor);
    }
 
    InMemoryBodyDataSource(String characterEncoding, IMultimodeExecutor executor, byte[] body) throws IOException {
        this(characterEncoding, executor, new ByteBuffer[] { ByteBuffer.wrap(body) });
    }
    
    
    InMemoryBodyDataSource(String characterEncoding, IMultimodeExecutor executor, ByteBuffer[] body) throws IOException {
        super(characterEncoding, executor, body);
        setComplete();
    }
    
 
   

    /**
     * {@inheritDoc}
     */
    @Override
    String getId() {
        return Integer.toString(hashCode());
    }

    
    /**
     * {@inheritDoc}
     */
    @Override
    void suspend() throws IOException {
        
    }


    /**
     * {@inheritDoc}
     */
    @Override
    boolean isSuspended() {
        return false;
    }

    
    /**
     * {@inheritDoc}
     */
    @Override
    void resume() throws IOException {
        
    }
  

    /**
     * {@inheritDoc}
     */
    @Override
    void onClose() {
    }

    
    /**
     * {@inheritDoc}
     */
    @Override
    void onDestroy(String reason) {
    }
}
	    
